@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2012 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -12,11 +12,12 @@
 
 
 
+
 qeunif <- function(p, min = 0, max = 1, Maxit_nr = 10, Tol_nr = 1.0e-6) {
 
-  ppp = p
-  vsmallno = sqrt(.Machine$double.eps)
-   smallno = 0.10
+  ppp <- p
+  vsmallno <- sqrt(.Machine$double.eps)
+   smallno <- 0.10
   if (any(min >= max))
     stop("argument 'min' has values greater or equal ",
          "to argument 'max'")
@@ -24,16 +25,16 @@ qeunif <- function(p, min = 0, max = 1, Maxit_nr = 10, Tol_nr = 1.0e-6) {
       Tol_nr > 0.10)
     stop("argument 'Tol_nr' is not a single positive value, ",
          "or is too large")
-  nrok = ppp >= vsmallno & ppp <= 1.0 - vsmallno & is.finite(ppp)
+  nrok <- ppp >= vsmallno & ppp <= 1.0 - vsmallno & is.finite(ppp)
 
-  eee = qbeta(ppp, shape1 = 3, shape2 = 3)
-  eee[ppp <        smallno] = sqrt(ppp[ppp <  smallno])
-  eee[ppp > 1.0 -  smallno] = 1.0 - sqrt(1.0 - ppp[ppp > 1.0 -  smallno])
+  eee <- qbeta(ppp, shape1 = 3, shape2 = 3)
+  eee[ppp <        smallno] <- sqrt(ppp[ppp <  smallno])
+  eee[ppp > 1.0 -  smallno] <- 1.0 - sqrt(1.0 - ppp[ppp > 1.0 -  smallno])
 
 
   for(iii in 1:Maxit_nr) {
     realdiff <- (peunif(eee[nrok]) - ppp[nrok]) / deunif(eee[nrok])
-    eee[nrok] = eee[nrok] - realdiff
+    eee[nrok] <- eee[nrok] - realdiff
     if (all(abs(realdiff) / (1.0 + abs(realdiff)) < Tol_nr )) break
     if (iii == Maxit_nr) warning("did not converge")
   }
@@ -41,12 +42,12 @@ qeunif <- function(p, min = 0, max = 1, Maxit_nr = 10, Tol_nr = 1.0e-6) {
   if (max(abs(peunif(eee[nrok]) - ppp[nrok])) > Tol_nr)
     warning("did not converge on the second check")
 
-  eee[ppp <       vsmallno] =       sqrt(      ppp[ppp <       vsmallno])
-  eee[ppp > 1.0 - vsmallno] = 1.0 - sqrt(1.0 - ppp[ppp > 1.0 - vsmallno])
-  eee[ppp == 0] = 0
-  eee[ppp == 1] = 1
-  eee[ppp <  0] = NA
-  eee[ppp >  1] = NA
+  eee[ppp <       vsmallno] <-       sqrt(      ppp[ppp <       vsmallno])
+  eee[ppp > 1.0 - vsmallno] <- 1.0 - sqrt(1.0 - ppp[ppp > 1.0 - vsmallno])
+  eee[ppp == 0] <- 0
+  eee[ppp == 1] <- 1
+  eee[ppp <  0] <- NA
+  eee[ppp >  1] <- NA
   min + eee * (max - min)
 }
 
@@ -58,16 +59,16 @@ peunif <- function(q, min = 0, max = 1, log = FALSE) {
   if (any(min >= max))
     stop("argument 'min' has values greater or equal to argument 'max'")
 
-  eee = (q - min) / (max - min)
+  eee <- (q - min) / (max - min)
   if (log.arg) {
-    logGofy = 2 * log(eee) - log1p(2 * eee * (eee - 1))
-    logGofy[eee < 0] = -Inf
-    logGofy[eee > 1] = 0.0
+    logGofy <- 2 * log(eee) - log1p(2 * eee * (eee - 1))
+    logGofy[eee < 0] <- -Inf
+    logGofy[eee > 1] <- 0.0
     logGofy
   } else {
-    Gofy = eee^2 / (1 + 2 * eee * (eee - 1))
-    Gofy[eee < 0] = 0.0
-    Gofy[eee > 1] = 1.0
+    Gofy <- eee^2 / (1 + 2 * eee * (eee - 1))
+    Gofy[eee < 0] <- 0.0
+    Gofy[eee > 1] <- 1.0
     Gofy
   }
 }
@@ -81,17 +82,17 @@ deunif <- function(x, min = 0, max = 1, log = FALSE) {
   if (any(min >= max))
     stop("argument 'min' has values greater or equal to argument 'max'")
 
-  eee = (x - min) / (max - min)
+  eee <- (x - min) / (max - min)
 
   if (log.arg) {
-    ans = log(2) + log(eee) + log1p(-eee) -
-          2.0 * log(2*eee*(1-eee) - 1) - log(max - min)
-    ans[eee <= 0.0] = log(0.0)
-    ans[eee >= 1.0] = log(0.0)
+    ans <- log(2) + log(eee) + log1p(-eee) -
+           2.0 * log(2*eee*(1-eee) - 1) - log(max - min)
+    ans[eee <= 0.0] <- log(0.0)
+    ans[eee >= 1.0] <- log(0.0)
   } else {
     gunif <- function(y)
         as.numeric(y >= 0 & y <= 1) * 2*y*(1-y) / (2*y*(1-y) - 1)^2
-    ans = gunif(eee) / (max - min)
+    ans <- gunif(eee) / (max - min)
   }
   ans
 }
@@ -100,12 +101,8 @@ deunif <- function(x, min = 0, max = 1, log = FALSE) {
 
 
 reunif <- function(n, min = 0, max = 1) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE,
-                          allowable.length = 1, positive = TRUE))
-            stop("bad input for argument 'n'") else n
 
-  qeunif(runif(use.n), min = min, max = max)
+  qeunif(runif(n), min = min, max = max)
 }
 
 
@@ -114,21 +111,21 @@ reunif <- function(n, min = 0, max = 1) {
 
 qenorm <- function(p, mean = 0, sd = 1, Maxit_nr = 10,
                    Tol_nr = 1.0e-6) {
-  ppp = p
+  ppp <- p
   if (!is.Numeric( Tol_nr, allowable.length = 1, positive = TRUE) ||
       Tol_nr > 0.10)
     stop("argument 'Tol_nr' is not a single ",
          "positive value, or is too large")
-  nrok = is.finite(ppp)
+  nrok <- is.finite(ppp)
 
-  eee =  qnorm(ppp, sd = 2/3)
+  eee <-  qnorm(ppp, sd = 2/3)
 
 
-  gnorm = function(y) dnorm(y) / (y * (1-2*pnorm(y)) - 2*dnorm(y))^2
+  gnorm <- function(y) dnorm(y) / (y * (1-2*pnorm(y)) - 2*dnorm(y))^2
 
   for(iii in 1:Maxit_nr) {
     realdiff <- (penorm(eee[nrok]) - ppp[nrok]) / gnorm(eee[nrok])
-    eee[nrok] = eee[nrok] - realdiff
+    eee[nrok] <- eee[nrok] - realdiff
     if (all(abs(realdiff) / (1.0 + abs(realdiff)) < Tol_nr )) break
     if (iii == Maxit_nr) warning("did not converge")
   }
@@ -136,10 +133,10 @@ qenorm <- function(p, mean = 0, sd = 1, Maxit_nr = 10,
   if (max(abs(penorm(eee[nrok]) - ppp[nrok])) > Tol_nr)
     warning("did not converge on the second check")
 
-  eee[ppp == 0] = -Inf
-  eee[ppp == 1] =  Inf
-  eee[ppp <  0] = NA
-  eee[ppp >  1] = NA
+  eee[ppp == 0] <- -Inf
+  eee[ppp == 1] <-  Inf
+  eee[ppp <  0] <- NA
+  eee[ppp >  1] <- NA
   eee * ifelse(sd >= 0, sd, NaN) + mean
 }
 
@@ -149,17 +146,17 @@ penorm <- function(q, mean = 0, sd = 1, log = FALSE) {
     stop("bad input for argument 'log'")
   rm(log)
 
-  eee = (q - mean) / sd
-  tmp1 = -dnorm(eee) - eee * pnorm(eee)
+  eee <- (q - mean) / sd
+  tmp1 <- -dnorm(eee) - eee * pnorm(eee)
   if (log.arg) {
-    logGofy = log(tmp1) - log(2 * tmp1 + eee)
-    logGofy[eee <= -Inf] = -Inf
-    logGofy[eee >=  Inf] = 0.0
+    logGofy <- log(tmp1) - log(2 * tmp1 + eee)
+    logGofy[eee <= -Inf] <- -Inf
+    logGofy[eee >=  Inf] <- 0.0
     logGofy
   } else {
-    Gofy = tmp1 / (2 * tmp1 + eee)
-    Gofy[eee <= -Inf] = 0.0
-    Gofy[eee >=  Inf] = 1.0
+    Gofy <- tmp1 / (2 * tmp1 + eee)
+    Gofy[eee <= -Inf] <- 0.0
+    Gofy[eee >=  Inf] <- 1.0
     Gofy
   }
 }
@@ -170,14 +167,14 @@ denorm <- function(x, mean = 0, sd = 1, log = FALSE) {
     stop("bad input for argument 'log'")
   rm(log)
 
-  eee = (x - mean) / sd
+  eee <- (x - mean) / sd
   if (log.arg) {
-    ans = dnorm(eee, log = TRUE) -
-          2.0 * log(eee * (1-2*pnorm(eee)) - 2*dnorm(eee)) - log(sd)
+    ans <- dnorm(eee, log = TRUE) -
+           2.0 * log(eee * (1-2*pnorm(eee)) - 2*dnorm(eee)) - log(sd)
   } else {
-    gnorm = function(y) dnorm(y) / (y * (1-2*pnorm(y)) - 2*dnorm(y))^2
-    ans = gnorm(eee) / sd
-    ans[sd  <=  0.0] = NaN
+    gnorm <- function(y) dnorm(y) / (y * (1-2*pnorm(y)) - 2*dnorm(y))^2
+    ans <- gnorm(eee) / sd
+    ans[sd  <=  0.0] <- NaN
   }
   ans
 }
@@ -186,12 +183,8 @@ denorm <- function(x, mean = 0, sd = 1, log = FALSE) {
 
 
 renorm <- function(n, mean = 0, sd = 1) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE,
-                          allowable.length = 1, positive = TRUE))
-            stop("bad input for argument 'n'") else n
 
-  qenorm(runif(use.n), mean = mean, sd = sd)
+  qenorm(runif(n), mean = mean, sd = sd)
 }
 
 
@@ -201,26 +194,26 @@ renorm <- function(n, mean = 0, sd = 1) {
 
 
 qeexp <- function(p, rate = 1, Maxit_nr = 10, Tol_nr = 1.0e-6) {
-  ppp = p
-  vsmallno = sqrt(.Machine$double.eps)
+  ppp <- p
+  vsmallno <- sqrt(.Machine$double.eps)
   if (!is.Numeric( Tol_nr, allowable.length = 1, positive = TRUE) ||
       Tol_nr > 0.10)
     stop("argument 'Tol_nr' is not a single positive value, or ",
          "is too large")
-  nrok = ppp >= vsmallno & is.finite(ppp)
+  nrok <- ppp >= vsmallno & is.finite(ppp)
 
 
-  eee = qf(1.0 * ppp, df1 =  4.0, df2 = 44)
+  eee <- qf(1.0 * ppp, df1 =  4.0, df2 = 44)
   if ( any(rangex <- ppp < 0.8) )
-      eee[rangex] = qrayleigh(ppp[rangex], scale =  0.8)
+      eee[rangex] <- qrayleigh(ppp[rangex], scale =  0.8)
 
 
-  eee[ppp <       vsmallno] = sqrt(ppp[ppp < vsmallno])
+  eee[ppp <       vsmallno] <- sqrt(ppp[ppp < vsmallno])
 
 
   for(iii in 1:Maxit_nr) {
     realdiff <- (peexp(eee[nrok]) - ppp[nrok]) / deexp(eee[nrok])
-    eee[nrok] = eee[nrok] - realdiff
+    eee[nrok] <- eee[nrok] - realdiff
     if (all(abs(realdiff) / (1.0 + abs(realdiff)) < Tol_nr )) break
     if (iii == Maxit_nr) warning("did not converge")
   }
@@ -228,11 +221,11 @@ qeexp <- function(p, rate = 1, Maxit_nr = 10, Tol_nr = 1.0e-6) {
   if (max(abs(peexp(eee[nrok]) - ppp[nrok])) > Tol_nr)
     warning("did not converge on the second check")
 
-  eee[ppp < vsmallno] = sqrt(ppp[ppp < vsmallno])
-  eee[ppp == 0] = 0
-  eee[ppp == 1] = Inf
-  eee[ppp <  0] = NaN
-  eee[ppp >  1] = NaN
+  eee[ppp < vsmallno] <- sqrt(ppp[ppp < vsmallno])
+  eee[ppp == 0] <- 0
+  eee[ppp == 1] <- Inf
+  eee[ppp <  0] <- NaN
+  eee[ppp >  1] <- NaN
   eee / rate
 }
 
@@ -242,18 +235,18 @@ peexp <- function(q, rate = 1, log = FALSE) {
     stop("bad input for argument 'log'")
   rm(log)
 
-  eee = q * rate
+  eee <- q * rate
   if (log.arg) {
-    tmp1 = -expm1(-eee) - eee
-    logGofy = log1p(- eee - exp(-eee)) - log(2 * tmp1 + eee - 1.0)
-    logGofy[eee <    0] = log(0.0)
-    logGofy[eee >= Inf] = log(1.0)
+    tmp1 <- -expm1(-eee) - eee
+    logGofy <- log1p(- eee - exp(-eee)) - log(2 * tmp1 + eee - 1.0)
+    logGofy[eee <    0] <- log(0.0)
+    logGofy[eee >= Inf] <- log(1.0)
     logGofy
   } else {
-    tmp1 = -expm1(-eee) - eee
-    Gofy = tmp1 / (2 * tmp1 + eee - 1.0)
-    Gofy[eee <    0] = 0.0
-    Gofy[eee >= Inf] = 1.0
+    tmp1 <- -expm1(-eee) - eee
+    Gofy <- tmp1 / (2 * tmp1 + eee - 1.0)
+    Gofy[eee <    0] <- 0.0
+    Gofy[eee >= Inf] <- 1.0
     Gofy
   }
 }
@@ -267,15 +260,15 @@ deexp <- function(x, rate = 1, log = FALSE) {
   if (any(rate <= 0))
     stop("argument 'rate' must have positive values")
 
-  eee = x * rate
+  eee <- x * rate
 
   if (log.arg) {
-    ans = log(eee) - eee + 2.0 * log((1-x) - 2 * exp(-x)) + log(rate)
+    ans <- log(eee) - eee + 2.0 * log((1-x) - 2 * exp(-x)) + log(rate)
   } else {
-    gexp = function(y)
+    gexp <- function(y)
       as.numeric(y >= 0) * y * exp(-y) / ((1-y) - 2 * exp(-y))^2
-    ans = gexp(eee) * rate
-    ans[rate <=  0.0] = NaN
+    ans <- gexp(eee) * rate
+    ans[rate <=  0.0] <- NaN
   }
   ans
 }
@@ -283,11 +276,7 @@ deexp <- function(x, rate = 1, log = FALSE) {
 
 
 reexp <- function(n, rate = 1) {
-  use.n = if ((length.n <- length(n)) > 1) length.n else
-          if (!is.Numeric(n, integer.valued = TRUE,
-                          allowable.length = 1, positive = TRUE))
-              stop("bad input for argument 'n'") else n
-  qeexp(runif(use.n), rate = rate)
+  qeexp(runif(n), rate = rate)
 }
 
 
@@ -358,8 +347,7 @@ rkoenker <- function(n, location = 0, scale = 1) {
                      llocation = "identity", lscale = "loge",
                      ilocation = NULL,   iscale = NULL,
                      imethod = 1,
-                     zero = 2)
-{
+                     zero = 2) {
 
  
 
@@ -461,9 +449,9 @@ rkoenker <- function(n, location = 0, scale = 1) {
       for(ii in 1:length( .percentile )) {
         y.use <- if (ncoly > 1) y[, ii] else y
         mu <- cbind(mu)
-        extra$percentile[ii] = 100 * weighted.mean(y.use <= mu[, ii], w)
+        extra$percentile[ii] <- 100 * weighted.mean(y.use <= mu[, ii], w)
       }
-      names(extra$percentile) = colnames(mu)
+      names(extra$percentile) <- colnames(mu)
   }), list( .llocat = llocat, .lscale = lscale,
             .elocat = elocat, .escale = escale,
             .imethod = imethod, .percentile = percentile ))),
@@ -497,12 +485,12 @@ rkoenker <- function(n, location = 0, scale = 1) {
   }), list( .llocat = llocat, .lscale = lscale,
             .elocat = elocat, .escale = escale ))),
   weight = eval(substitute(expression({
-    ed2l.dlocat2 <- 0.3 / Scale^2
-    ed2l.dscale2 <- 2.0 / (3 * Scale^2)
+    ned2l.dlocat2 <- 0.3 / Scale^2
+    ned2l.dscale2 <- 2.0 / (3 * Scale^2)
 
-    wz <- matrix(-10, n, M)  # Diagonal EIM
-    wz[, iam(1, 1, M = M)] <- ed2l.dlocat2 * dlocat.deta^2
-    wz[, iam(2, 2, M = M)] <- ed2l.dscale2 * dscale.deta^2
+    wz <- matrix(-10, n, M) # Diagonal EIM
+    wz[, iam(1, 1, M = M)] <- ned2l.dlocat2 * dlocat.deta^2
+    wz[, iam(2, 2, M = M)] <- ned2l.dscale2 * dscale.deta^2
 
     c(w) * wz
   }), list( .llocat = llocat, .lscale = lscale,
